"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _svgChart = _interopRequireDefault(require("./svgChart"));
var echarts = _interopRequireWildcard(require("echarts/core"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const LazyLoadingChartView = /*#__PURE__*/(0, _react.memo)( /*#__PURE__*/(0, _react.forwardRef)((_ref, ref) => {
  let {
    option,
    width,
    height,
    theme
  } = _ref;
  const [chart, setChart] = (0, _react.useState)();
  const chartRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(() => {
    let _chart;
    if (chartRef.current) {
      if (!chart) {
        // @ts-ignore
        _chart = echarts.init(chartRef.current, theme, {
          renderer: 'svg',
          height,
          width
        });
        _chart.setOption(option ?? {});
        setChart(_chart);
      }
    }
  }, [option, theme, chart, chartRef, height, width]);
  (0, _react.useEffect)(() => {
    if (chart) {
      chart.setOption(option ?? {});
    }
  }, [chart, option]);
  (0, _react.useEffect)(() => {
    if (chart) {
      chart.resize({
        height,
        width
      });
    }
  }, [height, width, chart]);
  (0, _react.useImperativeHandle)(ref, () => ({
    // eslint-disable-next-line @typescript-eslint/no-shadow
    setOption: function (option) {
      let ops = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : undefined;
      chart === null || chart === void 0 ? void 0 : chart.setOption(option, ops);
    },
    getChart: () => chart
  }), [chart]);
  return /*#__PURE__*/_react.default.createElement(_svgChart.default, {
    ref: chartRef
  });
}));
const ChartView = (_ref2, ref) => {
  let {
    style,
    option,
    theme = 'light',
    height = _ref3 => {
      let {
        _height
      } = _ref3;
      return _height;
    },
    width = _ref4 => {
      let {
        _width
      } = _ref4;
      return _width;
    },
    lazyloading = true
  } = _ref2;
  const chartRef = (0, _react.useRef)(null);
  const [chartHeight, setChartHeight] = (0, _react.useState)(0);
  const [chartWidth, setChartWidth] = (0, _react.useState)(0);
  const [viewHeight, setViewHeight] = (0, _react.useState)(0);
  const [viewWidth, setViewWidth] = (0, _react.useState)(0);
  const [LazyLoadingFlg, setLazyLoadingFlg] = (0, _react.useState)(lazyloading);
  (0, _react.useEffect)(() => {
    if (LazyLoadingFlg) {
      setTimeout(() => {
        setLazyLoadingFlg(false);
      }, 400);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  (0, _react.useImperativeHandle)(ref, () => ({
    // eslint-disable-next-line @typescript-eslint/no-shadow
    setOption: function (option) {
      var _chartRef$current;
      let ops = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : undefined;
      (_chartRef$current = chartRef.current) === null || _chartRef$current === void 0 ? void 0 : _chartRef$current.setOption(option, ops);
    },
    getChart: () => {
      var _chartRef$current2;
      return (_chartRef$current2 = chartRef.current) === null || _chartRef$current2 === void 0 ? void 0 : _chartRef$current2.getChart();
    }
  }), [chartRef]);
  (0, _react.useEffect)(() => {
    if (typeof height === 'number' && height > 0) {
      setChartHeight(height);
    } else if (typeof height === 'function') {
      let _h = height({
        _width: viewWidth,
        _height: viewHeight
      });
      if (_h && _h > 0) setChartHeight(_h);
    } else {
      setChartHeight(viewHeight);
    }
  }, [height, viewHeight, viewWidth]);
  (0, _react.useEffect)(() => {
    if (typeof width === 'number' && width > 0) {
      setChartWidth(width);
    } else if (viewWidth > 0 && typeof width === 'function') {
      let _w = width({
        _width: viewWidth,
        _height: viewHeight
      });
      if (_w) setChartWidth(_w);
    } else {
      setChartWidth(viewWidth);
    }
  }, [width, viewWidth, viewHeight]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    onLayout: ev => {
      setViewHeight(Math.round(ev.nativeEvent.layout.height));
      setViewWidth(Math.round(ev.nativeEvent.layout.width));
    }
    // eslint-disable-next-line react-native/no-inline-styles
    ,
    style: [style, {
      flex: 1,
      height: '100%',
      width: '100%'
    }]
  }, !LazyLoadingFlg && chartWidth && chartHeight && /*#__PURE__*/_react.default.createElement(LazyLoadingChartView, {
    option: option,
    theme: theme,
    width: chartWidth,
    height: chartHeight,
    ref: chartRef
  }));
};
var _default = /*#__PURE__*/(0, _react.memo)( /*#__PURE__*/(0, _react.forwardRef)(ChartView));
exports.default = _default;
//# sourceMappingURL=chartView.js.map