import React, { forwardRef, memo, useImperativeHandle } from 'react';
import { useEffect, useRef, useState } from 'react';
import { View } from 'react-native';
import SvgChart from './svgChart';
import * as echarts from 'echarts/core';
const LazyLoadingChartView = /*#__PURE__*/memo( /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    option,
    width,
    height,
    theme
  } = _ref;
  const [chart, setChart] = useState();
  const chartRef = useRef(null);
  useEffect(() => {
    let _chart;
    if (chartRef.current) {
      if (!chart) {
        // @ts-ignore
        _chart = echarts.init(chartRef.current, theme, {
          renderer: 'svg',
          height,
          width
        });
        _chart.setOption(option ?? {});
        setChart(_chart);
      }
    }
  }, [option, theme, chart, chartRef, height, width]);
  useEffect(() => {
    if (chart) {
      chart.setOption(option ?? {});
    }
  }, [chart, option]);
  useEffect(() => {
    if (chart) {
      chart.resize({
        height,
        width
      });
    }
  }, [height, width, chart]);
  useImperativeHandle(ref, () => ({
    // eslint-disable-next-line @typescript-eslint/no-shadow
    setOption: function (option) {
      let ops = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : undefined;
      chart === null || chart === void 0 ? void 0 : chart.setOption(option, ops);
    },
    getChart: () => chart
  }), [chart]);
  return /*#__PURE__*/React.createElement(SvgChart, {
    ref: chartRef
  });
}));
const ChartView = (_ref2, ref) => {
  let {
    style,
    option,
    theme = 'light',
    height = _ref3 => {
      let {
        _height
      } = _ref3;
      return _height;
    },
    width = _ref4 => {
      let {
        _width
      } = _ref4;
      return _width;
    },
    lazyloading = true
  } = _ref2;
  const chartRef = useRef(null);
  const [chartHeight, setChartHeight] = useState(0);
  const [chartWidth, setChartWidth] = useState(0);
  const [viewHeight, setViewHeight] = useState(0);
  const [viewWidth, setViewWidth] = useState(0);
  const [LazyLoadingFlg, setLazyLoadingFlg] = useState(lazyloading);
  useEffect(() => {
    if (LazyLoadingFlg) {
      setTimeout(() => {
        setLazyLoadingFlg(false);
      }, 400);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  useImperativeHandle(ref, () => ({
    // eslint-disable-next-line @typescript-eslint/no-shadow
    setOption: function (option) {
      var _chartRef$current;
      let ops = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : undefined;
      (_chartRef$current = chartRef.current) === null || _chartRef$current === void 0 ? void 0 : _chartRef$current.setOption(option, ops);
    },
    getChart: () => {
      var _chartRef$current2;
      return (_chartRef$current2 = chartRef.current) === null || _chartRef$current2 === void 0 ? void 0 : _chartRef$current2.getChart();
    }
  }), [chartRef]);
  useEffect(() => {
    if (typeof height === 'number' && height > 0) {
      setChartHeight(height);
    } else if (typeof height === 'function') {
      let _h = height({
        _width: viewWidth,
        _height: viewHeight
      });
      if (_h && _h > 0) setChartHeight(_h);
    } else {
      setChartHeight(viewHeight);
    }
  }, [height, viewHeight, viewWidth]);
  useEffect(() => {
    if (typeof width === 'number' && width > 0) {
      setChartWidth(width);
    } else if (viewWidth > 0 && typeof width === 'function') {
      let _w = width({
        _width: viewWidth,
        _height: viewHeight
      });
      if (_w) setChartWidth(_w);
    } else {
      setChartWidth(viewWidth);
    }
  }, [width, viewWidth, viewHeight]);
  return /*#__PURE__*/React.createElement(View, {
    onLayout: ev => {
      setViewHeight(Math.round(ev.nativeEvent.layout.height));
      setViewWidth(Math.round(ev.nativeEvent.layout.width));
    }
    // eslint-disable-next-line react-native/no-inline-styles
    ,
    style: [style, {
      flex: 1,
      height: '100%',
      width: '100%'
    }]
  }, !LazyLoadingFlg && chartWidth && chartHeight && /*#__PURE__*/React.createElement(LazyLoadingChartView, {
    option: option,
    theme: theme,
    width: chartWidth,
    height: chartHeight,
    ref: chartRef
  }));
};
export default /*#__PURE__*/memo( /*#__PURE__*/forwardRef(ChartView));
//# sourceMappingURL=chartView.js.map